@@ -1,6 +1,11 @@
 function showClouseau(context) {
-    var footer = document.getElementById("region-content").nextSibling;
-    var wrapper = document.getElementById("region-content").parentNode;
+	content_node = document.getElementById("content-core")
+	if (content_node == null) {
+		// preserve compatibility with Plone 3
+		content_node = document.getElementById("region-content")
+	}
+    var footer = content_node.nextSibling;
+    var wrapper = content_node.parentNode;
     
     var div = document.createElement("div");
     var iframe = document.createElement("iframe");
